![Alt text](docs/img/wacc-logo.png?raw=true "Title")
<p align="center">
    <em>WACC - The Python micro framework for deriving cost of capital</em>
</p>
<p align="center">
      <a href="https://codecov.io/gh/pax1a/wacc">
        <img src="https://codecov.io/gh/pax1a/wacc/branch/main/graph/badge.svg?token=6CVZ1XENIV"/>
      </a>
</p>

    
---

**Documentation**: <a href="https://py.wacc.io" target="_blank">https://py.wacc.io</a>

**Source Code**: <a href="https://github.com/pax1a/wacc" target="_blank">https://github.com/pax1a/wacc</a>

---
